-- config/acinclude.m4
+++ config/acinclude.m4	2002/04/08 23:13:37
@@ -0,0 +1,61 @@
+dnl Configure-time switch with default
+dnl
+dnl Each switch defines an --enable-FOO and --disable-FOO option in
+dnl the resulting configure script.
+dnl
+dnl Usage:
+dnl SMR_SWITCH(name, description, default, pos-def, neg-def)
+dnl
+dnl where:
+dnl
+dnl name        name of switch; generates --enable-name & --disable-name
+dnl             options
+dnl description help string is set to this prefixed by "enable" or
+dnl             "disable", whichever is the non-default value
+dnl default     either "on" or "off"; specifies default if neither
+dnl             --enable-name nor --disable-name is specified
+dnl pos-def     a symbol to AC_DEFINE if switch is on (optional)
+dnl neg-def     a symbol to AC_DEFINE if switch is off (optional)
+dnl
+AC_DEFUN(SMR_SWITCH, [
+    AC_MSG_CHECKING(whether to enable $2)
+    AC_ARG_ENABLE(
+        $1,
+        ifelse($3, on,
+            [  --disable-[$1]    disable [$2]],
+            [  --enable-[$1]     enable [$2]]),
+        [ if test "$enableval" = yes; then
+            AC_MSG_RESULT(yes)
+            ifelse($4, , , AC_DEFINE($4))
+        else
+            AC_MSG_RESULT(no)
+            ifelse($5, , , AC_DEFINE($5))
+        fi ],
+        ifelse($3, on,
+           [ AC_MSG_RESULT(yes)
+             ifelse($4, , , AC_DEFINE($4)) ],
+           [ AC_MSG_RESULT(no)
+            ifelse($5, , , AC_DEFINE($5))]))])
+
+dnl
+dnl Examine size_t and define SIZE_T_IS_UINT, if size_t is an unsigned int
+dnl
+AC_DEFUN(OJ_SIZE_T_IS_UINT,[
+	AC_REQUIRE([AC_TYPE_SIZE_T])
+	AC_MSG_CHECKING(whether size_t is unsigned int)
+	ac_cv_size_t_is_uint=no
+	AC_LANG_SAVE
+	AC_LANG_CPLUSPLUS
+	AC_TRY_COMPILE([#include <unistd.h>
+
+                       template<class T> class foo { };
+
+                        ], [
+			foo<size_t> x;
+			foo<unsigned int> y;
+			x = y;
+		],ac_cv_size_t_is_uint=yes)
+	AC_LANG_RESTORE
+	AC_MSG_RESULT($ac_cv_size_t_is_uint)
+	test "$ac_cv_size_t_is_uint" = "yes" && AC_DEFINE(SIZE_T_IS_UINT)
+])
Index: openjade-1.3.2/config/acinclude.m4
===================================================================
--- openjade-1.3.2.orig/config/acinclude.m4
+++ openjade-1.3.2/config/acinclude.m4
@@ -1,3 +1,64 @@
+dnl Configure-time switch with default
+dnl
+dnl Each switch defines an --enable-FOO and --disable-FOO option in
+dnl the resulting configure script.
+dnl
+dnl Usage:
+dnl SMR_SWITCH(name, description, default, pos-def, neg-def)
+dnl
+dnl where:
+dnl
+dnl name        name of switch; generates --enable-name & --disable-name
+dnl             options
+dnl description help string is set to this prefixed by "enable" or
+dnl             "disable", whichever is the non-default value
+dnl default     either "on" or "off"; specifies default if neither
+dnl             --enable-name nor --disable-name is specified
+dnl pos-def     a symbol to AC_DEFINE if switch is on (optional)
+dnl neg-def     a symbol to AC_DEFINE if switch is off (optional)
+dnl
+AC_DEFUN(SMR_SWITCH, [
+    AC_MSG_CHECKING(whether to enable $2)
+    AC_ARG_ENABLE(
+        $1,
+        ifelse($3, on,
+            [  --disable-[$1]    disable [$2]],
+            [  --enable-[$1]     enable [$2]]),
+        [ if test "$enableval" = yes; then
+            AC_MSG_RESULT(yes)
+            ifelse($4, , , AC_DEFINE($4))
+        else
+            AC_MSG_RESULT(no)
+            ifelse($5, , , AC_DEFINE($5))
+        fi ],
+        ifelse($3, on,
+           [ AC_MSG_RESULT(yes)
+             ifelse($4, , , AC_DEFINE($4)) ],
+           [ AC_MSG_RESULT(no)
+            ifelse($5, , , AC_DEFINE($5))]))])
+
+dnl
+dnl Examine size_t and define SIZE_T_IS_UINT, if size_t is an unsigned int
+dnl
+AC_DEFUN(OJ_SIZE_T_IS_UINT,[
+	AC_REQUIRE([AC_TYPE_SIZE_T])
+	AC_MSG_CHECKING(whether size_t is unsigned int)
+	ac_cv_size_t_is_uint=no
+	AC_LANG_SAVE
+	AC_LANG_CPLUSPLUS
+	AC_TRY_COMPILE([#include <unistd.h>
+
+                       template<class T> class foo { };
+
+                        ], [
+			foo<size_t> x;
+			foo<unsigned int> y;
+			x = y;
+		],ac_cv_size_t_is_uint=yes)
+	AC_LANG_RESTORE
+	AC_MSG_RESULT($ac_cv_size_t_is_uint)
+	test "$ac_cv_size_t_is_uint" = "yes" && AC_DEFINE(SIZE_T_IS_UINT)
+])
 dnl
 dnl Examine size_t and define SIZE_T_IS_UINT, if size_t is an unsigned int
 dnl
Index: openjade-1.3.2/config/aclocal.m4
===================================================================
--- openjade-1.3.2.orig/config/aclocal.m4
+++ openjade-1.3.2/config/aclocal.m4
@@ -3352,7 +3352,7 @@ dnl Each switch defines an --enable-FOO
 dnl the resulting configure script.
 dnl
 dnl Usage:
-dnl smr_SWITCH(name, description, default, pos-def, neg-def)
+dnl SMR_SWITCH(name, description, default, pos-def, neg-def)
 dnl
 dnl where:
 dnl
@@ -3365,7 +3365,7 @@ dnl             --enable-name nor --disa
 dnl pos-def     a symbol to AC_DEFINE if switch is on (optional)
 dnl neg-def     a symbol to AC_DEFINE if switch is off (optional)
 dnl
-AC_DEFUN(smr_SWITCH, [
+AC_DEFUN(SMR_SWITCH, [
     AC_MSG_CHECKING(whether to enable $2)
     AC_ARG_ENABLE(
         $1,
Index: openjade-1.3.2/config/configure.in
===================================================================
--- openjade-1.3.2.orig/config/configure.in
+++ openjade-1.3.2/config/configure.in
@@ -243,8 +243,8 @@ AC_ARG_ENABLE(http,
 dnl
 dnl  optional backends
 dnl
-smr_SWITCH(mif, support for FrameMaker MIF output, on, JADE_MIF, DUMMY)
-smr_SWITCH(html, support for HTML+CSS output, on, JADE_HTML, DUMMY)
+SMR_SWITCH(mif, support for FrameMaker MIF output, on, JADE_MIF, DUMMY)
+SMR_SWITCH(html, support for HTML+CSS output, on, JADE_HTML, DUMMY)
 
 
 dnl 
